<?php
/**
 * serbian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Filip Brcic <brcha@users.sourceforge.net>
 * @author Иван Петровић (Ivan Petrovic) <petrovicivan@ubuntusrbija.org>
 * @author Miroslav Šolti <solti.miroslav@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '“';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '‘';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Измени ову страницу';
$lang['btn_source']            = 'Прикажи изворни код';
$lang['btn_show']              = 'Прикажи страницу';
$lang['btn_create']            = 'Направи ову страницу';
$lang['btn_search']            = 'Тражи';
$lang['btn_save']              = 'Сачувај';
$lang['btn_preview']           = 'Прегледај';
$lang['btn_top']               = 'Врати се на врх';
$lang['btn_newer']             = '<< новије';
$lang['btn_older']             = 'старије >>';
$lang['btn_revs']              = 'Старе верзије';
$lang['btn_recent']            = 'Скорије измене';
$lang['btn_upload']            = 'Пошаљи';
$lang['btn_cancel']            = 'Поништи';
$lang['btn_index']             = 'Индекс';
$lang['btn_secedit']           = 'Измени';
$lang['btn_login']             = 'Пријави се';
$lang['btn_logout']            = 'Одјави се';
$lang['btn_admin']             = 'Администрација';
$lang['btn_update']            = 'Ажурирај';
$lang['btn_delete']            = 'Избриши';
$lang['btn_back']              = 'Натраг';
$lang['btn_backlink']          = 'Повратне везе';
$lang['btn_backtomedia']       = 'Врати се на избор медијске датотеке';
$lang['btn_subscribe']         = 'Пријави се на измене';
$lang['btn_profile']           = 'Ажурирај профил';
$lang['btn_reset']             = 'Поништи';
$lang['btn_draft']             = 'Измени нацрт';
$lang['btn_recover']           = 'Опорави нацрт';
$lang['btn_draftdel']          = 'Обриши нацрт';
$lang['btn_revert']            = 'Врати на пређашњу верзију';
$lang['btn_register']          = 'Региструј се';
$lang['loggedinas']            = 'Пријављен као';
$lang['user']                  = 'Корисничко име';
$lang['pass']                  = 'Лозинка';
$lang['newpass']               = 'Нова лозинка';
$lang['oldpass']               = 'Потврди нову лозинку';
$lang['passchk']               = 'поново';
$lang['remember']              = 'Запамти ме';
$lang['fullname']              = 'Име и презиме';
$lang['email']                 = 'Е-адреса';
$lang['profile']               = 'Кориснички профил';
$lang['badlogin']              = 'Извините, није добро корисничко име или шифра.';
$lang['minoredit']             = 'Мала измена';
$lang['draftdate']             = 'Нацрт је аутоматски сачуван';
$lang['nosecedit']             = 'Страна је у међувремену промењена, поглавље је застарело и поново се учитава цела страна.';
$lang['regmissing']            = 'Извините, морате да попуните сва поља.';
$lang['reguexists']            = 'Извините, корисник са истим именом већ постоји.';
$lang['regsuccess']            = 'Корисник је направљен и лозинка је послата путем е-поште.';
$lang['regsuccess2']           = 'Корисник је направљен.';
$lang['regmailfail']           = 'Изгледа да је дошло до грешке приликом слања лозинке е-поштом. Молим Вас, контактирајте администратора!';
$lang['regbadmail']            = 'Дата е-адреса није у реду - ако мислите да је ово грешка, контактирајте администратора';
$lang['regbadpass']            = 'Две задате лозинке нису исте. Молим Вас, пробајте поново.';
$lang['regpwmail']             = 'Ваша DokuWiki лозинка';
$lang['reghere']               = 'Још увек немате налог? Само направите један';
$lang['profna']                = 'Овај вики не дозвољава измену профила';
$lang['profnochange']          = 'Нема промена.';
$lang['profnoempty']           = 'Није дозвољено оставити празно поље имена или е-адресе.';
$lang['profchanged']           = 'Кориснички профил је ажуриран.';
$lang['pwdforget']             = 'Заборавили сте лозинку? Направите нову';
$lang['resendna']              = 'Овај вики не дозвољава слање лозинки.';
$lang['resendpwdmissing']      = 'Жао ми је, сва поља морају бити попуњена.';
$lang['resendpwdnouser']       = 'Жао ми је, овај корисник не постоји у нашој бази.';
$lang['resendpwdbadauth']      = 'Жао ми је, потврдни код није исправан. Проверите да ли сте користили комплетан потврдни линк.';
$lang['resendpwdconfirm']      = 'Потврдни линк је постат као е-порука.';
$lang['resendpwdsuccess']      = 'Ваша нова лозинка је послата као е-порука.';
$lang['license']               = 'Осим где је другачије назначено, материјал на овом викију је под следећом лиценцом:';
$lang['licenseok']             = 'Напомена: Изменом ове стране слажете се да ће ваше измене бити под следећом лиценцом:';
$lang['searchmedia']           = 'Претражи по имену фајла';
$lang['searchmedia_in']        = 'Претражи у %s';
$lang['txt_upload']            = 'Изаберите датотеку за слање';
$lang['txt_filename']          = 'Унесите вики-име (опционо)';
$lang['txt_overwrt']           = 'Препишите тренутни фајл';
$lang['lockedby']              = 'Тренутно закључано од стране';
$lang['lockexpire']            = 'Закључавање истиче';
$lang['js']['willexpire']            = 'Ваше закључавање за измену ове странице ће да истекне за један минут.\nДа би сте избегли конфликте, искористите дугме за преглед како би сте ресетовали тајмер закључавања.';
$lang['js']['notsavedyet']     = 'Несачуване измене ће бити изгубљене.
Да ли стварно желите да наставите?';
$lang['js']['searchmedia']     = 'Потражи фајлове';
$lang['js']['keepopen']        = 'Задржи отворен прозор након одабира';
$lang['js']['hidedetails']     = 'Сакриј детаље';
$lang['js']['mediatitle']      = 'Подешаванја везе';
$lang['js']['mediadisplay']    = 'Тип везе';
$lang['js']['mediaalign']      = 'Поравнање';
$lang['js']['mediasize']       = 'Величина слике';
$lang['js']['mediatarget']     = 'веза води ка:';
$lang['js']['mediaclose']      = 'Затвори';
$lang['js']['mediainsert']     = 'Убаци';
$lang['js']['mediadisplayimg'] = 'Покажи слику';
$lang['js']['mediadisplaylnk'] = 'Покажи само везу';
$lang['js']['mediasmall']      = 'Мала верзија';
$lang['js']['mediamedium']     = 'Средња верзија';
$lang['js']['medialarge']      = 'Велика верзија';
$lang['js']['mediaoriginal']   = 'Оригинална верзија';
$lang['js']['medialnk']        = 'Веза ка страници са детаљима';
$lang['js']['mediadirect']     = 'Директна веза ка оригиналу';
$lang['js']['medianolnk']      = 'Без везе';
$lang['js']['medianolink']     = 'Не постављај слику као везу';
$lang['js']['medialeft']       = 'Поравнај слику на лево';
$lang['js']['mediaright']      = 'Поравнај слику на десно';
$lang['js']['mediacenter']     = 'Поравнај слику по средини';
$lang['js']['medianoalign']    = 'Без поравнања';
$lang['js']['nosmblinks']      = 'Повезивање са Windows дељеним фолдерима ради само у Мајкрософтовом Интернет Претраживачу.
Ипак, можете да ископирате и залепите везу.';
$lang['js']['linkwiz']         = 'Чаробњак за стварање везе';
$lang['js']['linkto']          = 'Повежи ка:';
$lang['js']['del_confirm']     = 'Обриши овај унос?';
$lang['rssfailed']             = 'Дошло је до грешке приликом преузимања овог довода: ';
$lang['nothingfound']          = 'Ништа није нађено.';
$lang['mediaselect']           = 'Избор медијске датотеке';
$lang['fileupload']            = 'Слање медијске датотеке';
$lang['uploadsucc']            = 'Успешно слање';
$lang['uploadfail']            = 'Неуспешно слање. Можда немате дозволу?';
$lang['uploadwrong']           = 'Слање је забрањено. Овај наставак датотеке је забрањен!';
$lang['uploadexist']           = 'Датотека већ постоји. Ништа није учињено.';
$lang['uploadbadcontent']      = 'Материјал који шаљете не одговара %s ';
$lang['uploadspam']            = 'Слање је блокирано јер се налазите на црној листи пошиљаоца.';
$lang['uploadxss']             = 'Слање је блокирано јер је потенцијално малициозног садржаја.';
$lang['uploadsize']            = 'Послата датотека је превелика. (максимум је %s)';
$lang['deletesucc']            = 'Фајл "%s" је избрисан.';
$lang['deletefail']            = '"%s" није могао да буде избрисан - проверите дозволе.';
$lang['mediainuse']            = 'Фајл "%s" није избрисан - још је у употреби.';
$lang['namespaces']            = 'Именски простори';
$lang['mediafiles']            = 'Доступни фајлови у';
$lang['accessdenied']          = 'Немате дозволу да видите ову страницу.';
$lang['mediausage']            = 'Користите следећу синтаксу за референцу ка овој датотеци:';
$lang['mediaview']             = 'Прикажи оригиналну датотеку';
$lang['mediaroot']             = 'почетак';
$lang['mediaupload']           = 'Пошаљи датотеку у тренутни именски простор. Да бисте направили подпросторе, предвидите их у поље „Пошаљи као“ раздвојено двотачкама.';
$lang['mediaextchange']        = 'Наставак датотеке је промењен из .%s у .%s!';
$lang['reference']             = 'Референце за';
$lang['ref_inuse']             = 'Фајл не може да буде избрисан јер га још увек користе следеће странице:';
$lang['ref_hidden']            = 'Неке референце су на страницама за које немате дозволе за читање';
$lang['hits']                  = 'Поготци';
$lang['quickhits']             = 'Имена страница које се поклапају';
$lang['toc']                   = 'Садржај';
$lang['current']               = 'тренутно';
$lang['yours']                 = 'Ваша верзија';
$lang['diff']                  = 'прикажи разлике до тренутне верзије';
$lang['diff2']                 = 'Прикажи разлике између одабраних ревизија';
$lang['difflink']              = 'Постави везу ка овом компаративном приказу';
$lang['line']                  = 'Линија';
$lang['breadcrumb']            = 'Траг';
$lang['youarehere']            = 'Сада сте овде';
$lang['lastmod']               = 'Последњи пут мењано';
$lang['by']                    = 'од';
$lang['deleted']               = 'избрисано';
$lang['created']               = 'направљено';
$lang['restored']              = 'стара верзија повраћена (%s)';
$lang['external_edit']         = 'спољна измена';
$lang['summary']               = 'Сажетак измене';
$lang['noflash']               = 'За приказивање ове врсте материјала потребан вам је <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
$lang['download']              = 'Преузми снипет';
$lang['mail_newpage']          = 'страница додата:';
$lang['mail_changed']          = 'страница измењена:';
$lang['mail_subscribe_list']   = 'Странице промењене у именском простору:';
$lang['mail_new_user']         = 'нови корисник:';
$lang['mail_upload']           = 'послата датотека:';
$lang['qb_bold']               = 'Мастан текст';
$lang['qb_italic']             = 'Курзивни текст';
$lang['qb_underl']             = 'Подвучени текст';
$lang['qb_code']               = 'Изворни код';
$lang['qb_strike']             = 'Прецртани текст';
$lang['qb_h1']                 = 'Наслов 1. нивоа';
$lang['qb_h2']                 = 'Наслов 2. нивоа';
$lang['qb_h3']                 = 'Наслов 3. нивоа';
$lang['qb_h4']                 = 'Наслов 4. нивоа';
$lang['qb_h5']                 = 'Наслов 5. нивоа';
$lang['qb_h']                  = 'Наслов';
$lang['qb_hs']                 = 'Одабери наслов';
$lang['qb_hplus']              = 'Виши наслов';
$lang['qb_hminus']             = 'Нижи наслов';
$lang['qb_hequal']             = 'Наслов на истом нивоу';
$lang['qb_link']               = 'Унутрашња веза';
$lang['qb_extlink']            = 'Спољашња веза';
$lang['qb_hr']                 = 'Хоризонтална линија';
$lang['qb_ol']                 = 'Елемент уређене листе';
$lang['qb_ul']                 = 'Елемент неуређене листе';
$lang['qb_media']              = 'Додај слике и друге фајлове';
$lang['qb_sig']                = 'Убаци потпис';
$lang['qb_smileys']            = 'Смешко';
$lang['qb_chars']              = 'Посебни карактери';
$lang['upperns']               = 'Скочи на виши именски простор';
$lang['admin_register']        = 'Додај новог корисника';
$lang['metaedit']              = 'Измени мета-податке';
$lang['metasaveerr']           = 'Записивање мета-података није било успешно';
$lang['metasaveok']            = 'Мета-подаци су сачувани';
$lang['img_backto']            = 'Натраг на';
$lang['img_title']             = 'Наслов';
$lang['img_caption']           = 'Назив';
$lang['img_date']              = 'Датум';
$lang['img_fname']             = 'Име фајла';
$lang['img_fsize']             = 'Величина';
$lang['img_artist']            = 'Фотограф';
$lang['img_copyr']             = 'Права копирања';
$lang['img_format']            = 'Формат';
$lang['img_camera']            = 'Камера';
$lang['img_keywords']          = 'Кључне речи';
$lang['subscr_subscribe_success'] = '%s је додат на списак претплатника %s';
$lang['subscr_subscribe_error'] = 'Грешка приликом додавања %s на списак претплатника %s';
$lang['subscr_subscribe_noaddress'] = 'Не постоји адреса повезана са вашим подацима, стога вас не можемо додати на списак претплатника.';
$lang['subscr_unsubscribe_success'] = '%s уклоњен са списка претплатника %s';
$lang['subscr_unsubscribe_error'] = 'Грешка приликом уклањања %s са списка претплатника %s';
$lang['subscr_already_subscribed'] = '%s је већ претплаћен на %s';
$lang['subscr_not_subscribed'] = '%s још није претплаћен на %s';
$lang['subscr_m_not_subscribed'] = 'Тренутно нисте претплаћени на ову страницу или именски простор.';
$lang['subscr_m_new_header']   = 'Додај претплату';
$lang['subscr_m_current_header'] = 'Тренутне претплате';
$lang['subscr_m_unsubscribe']  = 'Уклони претплату';
$lang['subscr_m_subscribe']    = 'Претплати се';
$lang['subscr_m_receive']      = 'Прими';
$lang['subscr_style_every']    = 'имејл о свакој промени';
$lang['subscr_style_digest']   = 'скраћени имејл о променама за сваку страницу (сваких %.2f дана)';
$lang['subscr_style_list']     = 'Списак страница промењених након последњег имејла (сваких %.2f дана)';
$lang['authtempfail']          = 'Провера корисника је тренутно недоступна. Ако се ситуација настави, молимо Вас да обавестите администратора викија.';
$lang['i_chooselang']          = 'Одаберите језик';
$lang['i_installer']           = 'Докувики инсталација';
$lang['i_wikiname']            = 'Назив викија';
$lang['i_enableacl']           = 'Укључи ';
$lang['i_superuser']           = 'Суперкорисник';
$lang['i_problems']            = 'Инсталација је наишла на проблеме који су навадени у тексту испод. Не можете наставити даље док их не исправите.';
$lang['i_modified']            = 'Из сигурносних разлога ова скрипта ради само са новом Dokuwiki инсталацијом. Требало би или да опет распакујете архиву преузету са сајта или да погледате <a href="http://dokuwiki.org/install">Dokuwiki инструкције за инсталацију</a>';
$lang['i_funcna']              = 'ПХП функција <code>%s</code> није доступна. Можда је Ваш хостинг провајдер забранио из неког разлога?';
$lang['i_phpver']              = '<code>%s</code> Верзија Вашег ПХПа је нижа од неопходне <code>%s</code>. Требало би да надоградите ПХП инсталацију.';
$lang['i_permfail']            = 'DokuWiki нема дозволу писања у <code>%s</code>. Потребно је да поправите дозволе за ову фасциклу!';
$lang['i_confexists']          = '<code>%s</code> већ постоји';
$lang['i_writeerr']            = 'Не могу да направим <code>%s</code>. Проверите дозволе а затим ручно направите ову датотеку.';
$lang['i_badhash']             = 'dokuwiki.php није препознат или је измењен (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - недозвољена или празна вредност';
$lang['i_success']             = 'Подешавања су завршена. Сада можете обрисати датотеку install.php. Наставите у <a href="doku.php?id=wiki:welcome">Ваш нови DokuWiki</a>.';
$lang['i_failure']             = 'Појавили су се проблеми при писању датотеке са подешавањима. Требало би да их ручно исправите пре него што ћете моћи да користите <a href="doku.php?id=wiki:welcome">Ваш нови DokuWiki</a>.';
$lang['i_policy']              = 'Иницијалне корисничке дозволе';
$lang['i_pol0']                = 'Отворени вики (читање, писање, слање датотека за све)';
$lang['i_pol1']                = 'Јавни вики (читање за све, писање и слање датотека само за регистроване кориснике)';
$lang['i_pol2']                = 'Затворени вики (читање, писање и слање датотека само за регистроване кориснике)';
$lang['i_retry']               = 'Понови';
$lang['i_license']             = 'Молимо вас, одаберите лиценцу под коју желите да ставите свој садржај:';
$lang['recent_global']         = 'Тренутно пратите промене у именском простору <b>%s</b>. Такође, можете пратити <a href="%s">прмене на целом викију</a>.';
$lang['years']                 = 'Пре %d година';
$lang['months']                = 'Пре %d месеци';
$lang['weeks']                 = 'Пре %d недеља';
$lang['days']                  = 'Пре %d дана';
$lang['hours']                 = 'Пре %d сати';
$lang['minutes']               = 'Пре %d минута';
$lang['seconds']               = 'Пре %d секунди';
$lang['wordblock']             = 'Ваше измене нису сачуване јер садрже забрањен текст (спам)';
